@@ -4,19 +4,19 @@ def read(path,auto_complete=True):
 	if auto_complete==True:
 		path='/sdcard/'+path
 		
-	df=pandas.read_csv(path)
+	df=pandas.read_csv(path,index_col=0)
 	return df
 
 
 
-def save(data,path,mode='a',auto_complete=True,auto_df=False,header=True):
+def save(data,path,mode='w',auto_complete=True,auto_df=False,header=True,index=True):
 	if auto_complete:
 		path='/sdcard/'+path
 		
 	if auto_df:
 		data=pandas.DataFrame(data=data)
 	
-	data.to_csv(path,mode=mode,index=False,header=header)
+	data.to_csv(path,mode=mode,index=index,header=header)
 	
 	
 	
@@ -69,6 +69,11 @@ class csv_operator:
 		return self.df.loc[pos[0],pos[1]]
 		
 		
+		
+	def row_search_data(self,given_col,data,target_col):
+		return list(self.df[self.df[given_col]==data][target_col])[0]
+		
+		
 	
 	def delete(self,name,mode):
 		if mode in [0,'row']:
@@ -76,6 +81,7 @@ class csv_operator:
 		elif mode in [1,'col']:
 			axis=1
 		self.df=self.df.drop(name,axis=axis)
+			
 		
 		
 		
